==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/el.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Θέμα υψηλής αντίθεσης",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ένα θέμα με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dark theme (beta)" : "Σκοτεινό θέμα (δοκιμαστική έκδοση)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ένα σκοτεινό θέμα το οποίο διευκολύνει τα μάτια σας μειώνοντας την συνολική ακτινοβολία και φωτεινότητα. Είναι ακόμη υπό δοκιμή, οπότε θα σας παρακαλούσαμε να αναφέρετε οποιαδήποτε προβλήματα παρατηρηθούν.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη προβλήματα που προκαλεί η δυσλεξία στην ανάγνωση",
    "Accessibility" : "Προσβασιμότητα",
    "Accessibility options for nextcloud" : "Ρυθμίσεις προσβασιμότητας του nextcloud.",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Προσφέρει πολλαπλές ρυθμίσεις προσβασιμότητας για να διευκολύνουν τη χρήση του Nextcloud",
    "Web Content Accessibility Guidelines" : "Οδηγίες προσβασιμότητας περιεχομένου ιστού",
    "our issue tracker" : "ο ανιχνευτής ζητημάτων μας",
    "our design team" : "η ομάδα σχεδιασμού μας",
    "Enable" : "Ενεργοποίηση"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/el.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Θέμα υψηλής αντίθεσης",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ένα θέμα με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ένα σκοτεινό θέμα το οποίο διευκολύνει τα μάτια σας μειώνοντας την συνολική ακτινοβολία και φωτεινότητα. Είναι ακόμη υπό δοκιμή, οπότε θα σας παρακαλούσαμε να αναφέρετε οποιαδήποτε προβλήματα παρατηρηθούν.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη προβλήματα που προκαλεί η δυσλεξία στην ανάγνωση",
    "Accessibility" : "Προσβασιμότητα",
    "Accessibility options for nextcloud" : "Ρυθμίσεις προσβασιμότητας του nextcloud.",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Προσφέρει πολλαπλές ρυθμίσεις προσβασιμότητας για να διευκολύνουν τη χρήση του Nextcloud",
    "Web Content Accessibility Guidelines" : "Οδηγίες προσβασιμότητας περιεχομένου ιστού",
    "our issue tracker" : "ο ανιχνευτής ζητημάτων μας",
    "our design team" : "η ομάδα σχεδιασμού μας",
    "Enable" : "Ενεργοποίηση",
    "Dark theme (beta)" : "Σκοτεινό θέμα (δοκιμαστική έκδοση)",
    "Themes" : "Θέματα",
    "Fonts" : "Γραμματοσειρές",
    "enabled" : "ενεργοποιημένο"
},
"nplurals=2; plural=(n != 1);");
